# Generated by roxygen2: do not edit by hand

S3method(plot,selecta)
S3method(print,selecta)
S3method(summary,selecta)
export(allocate)
export(assess)
export(cohort)
export(cohorts)
export(combine)
export(endpoint)
export(enroll)
export(exclude)
export(flowchart)
export(flowsave)
export(phase)
export(recdims)
export(sources)
export(stratify)
import(data.table)
import(grid)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grDevices,svg)
importFrom(grDevices,tiff)
importFrom(stats,setNames)
